; Copyright (C) 2023  Val Lorentz
; 
; This program is free software: you can redistribute it and/or modify it under the
; terms of the GNU Affero General Public License version 3, as published by the Free
; Software Foundation.
; 
; This program is distributed in the hope that it will be useful, but WITHOUT ANY
; WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
; PARTICULAR PURPOSE.  See the GNU Affero General Public License for more details.
; 
; You should have received a copy of the GNU Affero General Public License along with
; this program.  If not, see <http://www.gnu.org/licenses/>.

(ns jable.db
  (:require [clojure.tools.logging :refer :all]
            [clojure.string :as str]
            [jepsen [control :as c]
                    [db :as db]]
            [jepsen.control.util :as cu]
            [jepsen.control.core :as cc]
            [jepsen.control.scp :as scp]
            [jepsen.os.debian :as debian]))

(defn sable
  "Sable IRCd install from binaries in a local directory."
  [sable_bin_path]
  (reify db/DB
    (setup! [_ test node]
      (info node "installing Sable from" sable_bin_path)
      (c/exec "rm" "-rf" "/tmp/sable_upload")
      (c/exec "mkdir" "/tmp/sable_upload")
      (let [remote_bin_path (c/upload (map (fn [file] (str sable_bin_path file))
                                           ["auth_client" "listener_process" "sable_ircd"])
                                      "/tmp/sable_upload")]
        (c/su
          (c/exec* "cp" (str remote_bin_path "/*") "/usr/local/bin"))))

    (teardown! [_ test node]
      (info node "tearing down Sable"))))
